@@ -1,4 +1,4 @@
-sanitize_models <- function(models) {
+sanitize_models <- function(models, ...) {
 
     # fixest::fixest_multi
     # handles cases with `split` or with both `fsplit` and ` do this before
@@ -22,5 +22,9 @@ sanitize_models <- function(models) {
         models <- list(models)
     }
 
+    for (m in models) {
+        sanity_dots(m, ...)
+    }
+
     return(models)
 }
